@@ -22,14 +22,11 @@
 
 #include <QSharedData>
 
-namespace KMBox
-{
-
+namespace KMBox {
 class MBoxEntryPrivate : public QSharedData
 {
 public:
     MBoxEntryPrivate()
-        : mOffset(0), mMessageSize(0), mSeparatorSize(0)
     {
     }
 
@@ -41,11 +38,10 @@ public:
         mSeparatorSize = other.mSeparatorSize;
     }
 
-    quint64 mOffset;
-    quint64 mMessageSize;
-    quint64 mSeparatorSize;
+    quint64 mOffset = 0;
+    quint64 mMessageSize = 0;
+    quint64 mSeparatorSize = 0;
 };
-
 }
 
 #endif // KMBOX_MBOXENTRY_P_H
